@@ -18,6 +18,6 @@ class Text(ABC):
 
     @abstractmethod
     def get_segments(
-        self, include_text: bool = True, based_on: Optional["Text"] = None
+        self, include_text: bool = True, sort_based_on: Optional["Text"] = None
     ) -> ContextManagedGenerator[TextSegment, None, None]:
         ...
