@@ -1,25 +1,37 @@
+from .edit_operation import EditOperation
 from .hmm_word_alignment_model import HmmWordAlignmentModel
 from .ibm1_word_alignment_model import Ibm1WordAlignmentModel
 from .ibm2_word_alignment_model import Ibm2WordAlignmentModel
+from .phrase import Phrase
 from .symmetrization_heuristic import SymmetrizationHeuristic
 from .symmetrized_word_aligner import SymmetrizedWordAligner
 from .symmetrized_word_alignment_model import SymmetrizedWordAlignmentModel
 from .symmetrized_word_alignment_model_trainer import SymmetrizedWordAlignmentModelTrainer
 from .trainer import Trainer, TrainStats
+from .translation_engine import TranslationEngine
+from .translation_result import TranslationResult
+from .translation_result_builder import TranslationResultBuilder
+from .translation_sources import TranslationSources
 from .word_aligner import WordAligner
 from .word_alignment_matrix import WordAlignmentMatrix
 from .word_alignment_model import WordAlignmentModel
 
 __all__ = [
+    "EditOperation",
     "HmmWordAlignmentModel",
     "Ibm1WordAlignmentModel",
     "Ibm2WordAlignmentModel",
+    "Phrase",
     "SymmetrizationHeuristic",
     "SymmetrizedWordAligner",
     "SymmetrizedWordAlignmentModel",
     "SymmetrizedWordAlignmentModelTrainer",
     "TrainStats",
     "Trainer",
+    "TranslationEngine",
+    "TranslationResult",
+    "TranslationResultBuilder",
+    "TranslationSources",
     "WordAligner",
     "WordAlignmentMatrix",
     "WordAlignmentModel",
